==> easyapi-0.8.5.3-sources.jar: cn/easyutil/easyapi/logic/condition/MockProcess2.java <==
package cn.easyutil.easyapi.logic.condition;

import cn.easyutil.easyapi.content.ProjectContext;
import cn.easyutil.easyapi.entity.common.DocParamEntity;
import cn.easyutil.easyapi.entity.common.JavaType;
import cn.easyutil.easyapi.filter.operator.ReadMockTemplateOperator;
import com.alibaba.fastjson.JSONObject;

import java.util.*;

public class MockProcess2 {
    private ReadMockTemplateOperator filter;
    private int mockArraySize = 12;

    public static MockProcess2 with(ReadMockTemplateOperator filter){
        MockProcess2 mocker = new MockProcess2();
        mocker.filter = filter;
        return mocker;
    }

    public Object mockByApiParams(String param){
        return mockByApiParams(JSONObject.parseArray(param, DocParamEntity.class));
    }

    public Object mockByApiParams(List<DocParamEntity> params){
        Map<String,Object> result = new HashMap<>();
        mockByApiParams(params,result);
        if(result.size()==1 && result.containsKey(ProjectContext.nullKey)){
            return result.get(ProjectContext.nullKey);
        }
        return result;
    }

    public void mockByApiParams(List<DocParamEntity> params,Map<String,Object> result){
        if(params==null || params.size()==0){
            return ;
        }
        for (DocParamEntity param : params) {
            JavaType type = JavaType.getType(param.getJavaType());
            if(JavaType.isBaseType(type)){
                Object val = mockValue(param);
                param.setMockValue(val.toString());
                result.put(param.getName(),val);
                continue;
            }
            List<DocParamEntity> children = param.getChildren();
            Map<String,Object> childrenMap = new HashMap<>();
            switch (type){
                case Object:{
                    mockByApiParams(children,childrenMap);
                    result.put(param.getName(),childrenMap);
                    break;
                }
                case ArrayObject:{
                    List<Map<String,Object>> listChildren = new ArrayList<>();
                    for (int i = 0; i < mockArraySize; i++) {
                        childrenMap = new HashMap<>();
                        mockByApiParams(children,childrenMap);
                        listChildren.add(childrenMap);
                    }
                    result.put(param.getName(),listChildren);
                    break;
                }
                case Array:{
                    List<Object> listChildren = new ArrayList<>();
                    for (int i = 0; i < mockArraySize; i++) {
                        childrenMap = new HashMap<>();
                        mockByApiParams(children,childrenMap);
                        listChildren.add(childrenMap.get(ProjectContext.nullKey));
                    }
                    result.put(param.getName(), listChildren);
                    break;
                }
            }
        }
    }


    private Object mockValue(DocParamEntity entity){
        if(entity==null || entity.getJavaType()==null){
            return "";
        }
        String template = entity.getMockTemplate();
        JavaType javaType = JavaType.getType(entity.getJavaType());
        return filter.mock(template, javaType);
    }

    public void setMockArraySize(int mockArraySize) {
        this.mockArraySize = mockArraySize;
    }
}

==> easyapi-0.8.9-sources.jar: cn/easyutil/easyapi/logic/condition/MockProcess2.java <==
package cn.easyutil.easyapi.logic.condition;

import cn.easyutil.easyapi.content.ProjectContext;
import cn.easyutil.easyapi.entity.common.DocParamEntity;
import cn.easyutil.easyapi.entity.common.JavaType;
import cn.easyutil.easyapi.handler.extra.MockExtra;
import cn.easyutil.easyapi.handler.operator.MockReader;
import cn.easyutil.easyapi.handler.operator.provide.MockReaderProvider;
import com.alibaba.fastjson.JSONObject;

import java.util.*;

public class MockProcess2 {
    private MockReader filter;
    private int mockArraySize = 12;

    public static MockProcess2 with(MockReader filter){
        MockProcess2 mocker = new MockProcess2();
        mocker.filter = filter;
        return mocker;
    }

    public Object mockByApiParams(String param){
        return mockByApiParams(JSONObject.parseArray(param, DocParamEntity.class));
    }

    public Object mockByApiParams(List<DocParamEntity> params){
        Map<String,Object> result = new HashMap<>();
        mockByApiParams(params,result);
        if(result.size()==1 && result.containsKey(ProjectContext.nullKey)){
            return result.get(ProjectContext.nullKey);
        }
        return result;
    }

    public void mockByApiParams(List<DocParamEntity> params,Map<String,Object> result){
        if(params==null || params.size()==0){
            return ;
        }
        for (DocParamEntity param : params) {
            JavaType type = JavaType.getType(param.getJavaType());
            if(JavaType.isBaseType(type)){
                Object val = mockValue(param);
                param.setMockValue(val.toString());
                result.put(param.getName(),val);
                continue;
            }
            List<DocParamEntity> children = param.getChildren();
            Map<String,Object> childrenMap = new HashMap<>();
            switch (type){
                case Object:{
                    mockByApiParams(children,childrenMap);
                    result.put(param.getName(),childrenMap);
                    break;
                }
                case ArrayObject:{
                    List<Map<String,Object>> listChildren = new ArrayList<>();
                    for (int i = 0; i < mockArraySize; i++) {
                        childrenMap = new HashMap<>();
                        mockByApiParams(children,childrenMap);
                        listChildren.add(childrenMap);
                    }
                    result.put(param.getName(),listChildren);
                    break;
                }
                case Array:{
                    List<Object> listChildren = new ArrayList<>();
                    for (int i = 0; i < mockArraySize; i++) {
                        childrenMap = new HashMap<>();
                        mockByApiParams(children,childrenMap);
                        listChildren.add(childrenMap.get(ProjectContext.nullKey));
                    }
                    result.put(param.getName(), listChildren);
                    break;
                }
            }
        }
    }


    private Object mockValue(DocParamEntity entity){
        if(entity==null || entity.getJavaType()==null){
            return "";
        }
        String template = entity.getMockTemplate();
        JavaType javaType = JavaType.getType(entity.getJavaType());
        MockExtra extra = new MockExtra();
        extra.setTemplate(template);
        extra.setJavaType(javaType);
        return filter.mock(extra,null);
    }

    public void setMockArraySize(int mockArraySize) {
        this.mockArraySize = mockArraySize;
    }
}
